@@ -25,9 +25,9 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py 1879 2007-01-04 16:03:53Z wwalker $"
-__version__   = "$Revision: 1879 $"
-__date__      = "$Date: 2007-01-04 11:03:53 -0500 (Thu, 04 Jan 2007) $"
+__id__        = "$Id: braille.py 2223 2007-03-28 17:06:38Z wwalker $"
+__version__   = "$Revision: 2223 $"
+__date__      = "$Date: 2007-03-28 13:06:38 -0400 (Wed, 28 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -63,8 +63,8 @@ except:
     pass
 import debug
 import eventsynthesizer
+import orca_state
 import settings
-import util
 
 from orca_i18n import _                          # for gettext support
 from rolenames import getShortBrailleForRoleName # localized role names
@@ -158,12 +158,50 @@ BRL_FLG_REPEAT_DELAY  = 0x400000
 # ATM, the ones used in default.py are:
 #
 command_name = {}
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the left.
+#
 command_name[CMD_FWINLT]   = _("Line Left")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the right.
+#
 command_name[CMD_FWINRT]   = _("Line Right")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls up.
+#
 command_name[CMD_LNUP]     = _("Line Up")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls down.
+#
 command_name[CMD_LNDN]     = _("Line Down")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the top left of the
+# window.
+#
 command_name[CMD_TOP_LEFT] = _("Top Left")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to the bottom right of
+# the window.
+#
 command_name[CMD_BOT_LEFT] = _("Bottom Right")
+
+# Translators: this is a command for a button on a refreshable braille
+# display (an external hardware device used by people who are blind).
+# When pressing the button, the display scrolls to position containing
+# the cursor.
+#
 command_name[CMD_HOME]     = _("Cursor Position")
 
 # The size of the physical display (width, height).  The coordinate system of
@@ -311,8 +349,9 @@ class Text(Region):
         """
 
         self.accessible = accessible
-        [string, self.caretOffset, self.lineOffset] = \
-                 util.getTextLineAtCaret(self.accessible)
+        if orca_state.activeScript:
+            [string, self.caretOffset, self.lineOffset] = \
+                 orca_state.activeScript.getTextLineAtCaret(self.accessible)
 
         # Sometimes, gnome-terminal will give us very odd values when
         # the user is editing using 'vi' and has positioned the caret
@@ -345,7 +384,7 @@ class Text(Region):
         """
 
         [string, caretOffset, lineOffset] = \
-                 util.getTextLineAtCaret(self.accessible)
+                 orca_state.activeScript.getTextLineAtCaret(self.accessible)
         cursorOffset = caretOffset - lineOffset
         if self.label:
             cursorOffset += len(self.label.decode("UTF-8")) + 1
@@ -689,12 +728,12 @@ def refresh(panToCursor=True, targetCursorCell=0):
                 # The name before BrlTTY v3.8 revision 2810
                 #
                 writeStruct = brlapi.Write()
-            writeStruct.text = substring
             writeStruct.regionBegin = 1
             writeStruct.regionSize = len(substring.decode("UTF-8"))
             while writeStruct.regionSize < _displaySize[0]:
-                writeStruct.text += " "
+                substring += " "
                 writeStruct.regionSize += 1
+            writeStruct.text = substring
             writeStruct.cursor = cursorCell
             writeStruct.charset = "UTF-8"
 
@@ -926,26 +965,59 @@ def setupKeyRanges(keys):
     if not brlAPIRunning:
         return
 
-    # First, start by ignoring everything.
-    #
-    brlAPI.ignoreKeyRange(0,
-                          brlapi.KEY_FLAGS_MASK \
-                          | brlapi.KEY_TYPE_MASK \
-                          | brlapi.KEY_CODE_MASK)
+    try:
+        # First, start by ignoring everything.
+        #
+        brlAPI.ignoreKeys(brlapi.rangeType_all, [0])
 
-    # Next, enable cursor routing keys.
-    #
-    brlAPI.acceptKeyRange(brlapi.KEY_TYPE_CMD | brlapi.KEY_CMD_ROUTE,
-                          brlapi.KEY_TYPE_CMD \
-                          | brlapi.KEY_CMD_ROUTE | brlapi.KEY_CMD_ARG_MASK)
+        # Next, enable cursor routing keys.
+        #
+        keySet = [brlapi.KEY_TYPE_CMD | brlapi.KEY_CMD_ROUTE]
 
-    # Finally, enable the commands we care about.
-    #
-    keySet = []
-    for key in keys:
-        keySet.append(brlapi.KEY_TYPE_CMD | key)
-    if len(keySet):
-        brlAPI.acceptKeySet(keySet)
+        # Finally, enable the commands we care about.
+        #
+        for key in keys:
+            keySet.append(brlapi.KEY_TYPE_CMD | key)
+
+        brlAPI.acceptKeys(brlapi.rangeType_command, keySet)
+
+        debug.println(debug.LEVEL_FINEST, "Using BrlAPI v0.5.0+")
+    except:
+        debug.printException(debug.LEVEL_FINEST)
+        try:
+            # Old, incompatible way that was in v3.8 devel, but
+            # changed prior to release.  We need this just in case
+            # people have not updated yet.
+
+            # First, start by ignoring everything.
+            #
+            brlAPI.ignoreKeyRange(0,
+                                  brlapi.KEY_FLAGS_MASK \
+                                  | brlapi.KEY_TYPE_MASK \
+                                  | brlapi.KEY_CODE_MASK)
+
+            # Next, enable cursor routing keys.
+            #
+            brlAPI.acceptKeyRange(brlapi.KEY_TYPE_CMD | brlapi.KEY_CMD_ROUTE,
+                                  brlapi.KEY_TYPE_CMD \
+                                  | brlapi.KEY_CMD_ROUTE \
+                                  | brlapi.KEY_CMD_ARG_MASK)
+
+            # Finally, enable the commands we care about.
+            #
+            keySet = []
+            for key in keys:
+                keySet.append(brlapi.KEY_TYPE_CMD | key)
+            if len(keySet):
+                brlAPI.acceptKeySet(keySet)
+
+            debug.println(debug.LEVEL_FINEST,
+                          "Using BrlAPI pre-release v0.5.0")
+        except:
+            debug.printException(debug.LEVEL_FINEST)
+            debug.println(
+                debug.LEVEL_WARNING,
+                "Braille module cannot listen for braille input events")
 
 def init(callback=None, tty=7):
     """Initializes the braille module, connecting to the BrlTTY driver.
