@@ -19,9 +19,9 @@
 
 """Provides the FocusTrackingPresenter for Orca."""
 
-__id__        = "$Id: focus_tracking_presenter.py 2064 2007-02-27 16:46:00Z wwalker $"
-__version__   = "$Revision: 2064 $"
-__date__      = "$Date: 2007-02-27 11:46:00 -0500 (Tue, 27 Feb 2007) $"
+__id__        = "$Id: focus_tracking_presenter.py 2237 2007-04-02 20:42:19Z lmonsanto $"
+__version__   = "$Revision: 2237 $"
+__date__      = "$Date: 2007-04-02 16:42:19 -0400 (Mon, 02 Apr 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -40,7 +40,6 @@ import presentation_manager
 import rolenames
 import settings
 import speech
-import util
 
 from orca_i18n import _ # for gettext support
 
@@ -388,7 +387,11 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         #
         try:
             if event.source.role == rolenames.ROLE_TOOL_TIP:
-                return
+                # Check that it's okay to present tool tips. There
+                # is a bug in GTK versions prior to 2.10.11 that
+                # caused gnome-panel to crash.
+                if not settings.presentToolTips:
+                    return
         except:
             pass
 
@@ -481,14 +484,6 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                        or ((event.type == "focus:") \
                            and (event.source.role == rolenames.ROLE_FRAME)):
 
-                        # If old ("factory") settings don't exist yet, save
-                        # a set, else restore the old application settings.
-                        #
-                        if not self._oldAppSettings:
-                            self._oldAppSettings = util.saveOldAppSettings()
-                        else:
-                            util.restoreOldAppSettings(self._oldAppSettings)
-
                         # We'll let someone else decide if it's important
                         # to stop speech or not.
                         #speech.stop()
@@ -497,6 +492,16 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                         debug.println(debug.LEVEL_FINE, "ACTIVE SCRIPT: " \
                                       + orca_state.activeScript.name)
 
+                        # If old ("factory") settings don't exist yet, save
+                        # a set, else restore the old application settings.
+                        #
+                        if not self._oldAppSettings:
+                            self._oldAppSettings = \
+                                  orca_state.activeScript.saveOldAppSettings()
+                        else:
+                            orca_state.activeScript.restoreOldAppSettings( \
+                                                         self._oldAppSettings)
+
                         # Load in the application specific settings for the
                         # app for this event (if found).
                         #
@@ -750,6 +755,10 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                 if noFocus:
                     if settings.gilSleepTime:
                         time.sleep(settings.gilSleepTime)
+                    # Translators: this is intended to be a short phrase to
+                    # speak and braille to tell the user that no component
+                    # has keyboard focus.
+                    #
                     message = _("No focus")
                     if settings.brailleVerbosityLevel == \
                         settings.VERBOSITY_LEVEL_VERBOSE:
@@ -845,8 +854,6 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
     def activate(self):
         """Called when this presentation manager is activated."""
 
-        speech.speak(_("Switching to focus tracking mode."))
-
         self._listenerCounts = {}
         self._knownScripts   = {}
         self._knownAppSettings = {}
@@ -863,7 +870,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         self._registerEventListener("window:deactivate")
         self._registerEventListener("object:children-changed:remove")
 
-        win = util.findActiveWindow()
+        win = orca_state.activeScript.findActiveWindow()
         if win:
             # Generate a fake window activation event so the application
             # can tell the user about itself.
