@@ -33,9 +33,9 @@ created in their own module.  The module defining the Script subclass
 is also required to have a 'getScript(app)' method that returns an
 instance of the Script subclass.  See default.py for an example."""
 
-__id__        = "$Id: script.py 1996 2007-02-11 18:07:28Z joanied $"
-__version__   = "$Revision: 1996 $"
-__date__      = "$Date: 2007-02-11 13:07:28 -0500 (Sun, 11 Feb 2007) $"
+__id__        = "$Id: script.py 2219 2007-03-28 14:10:49Z richb $"
+__version__   = "$Revision: 2219 $"
+__date__      = "$Date: 2007-03-28 10:10:49 -0400 (Wed, 28 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -46,6 +46,7 @@ import keybindings
 import orca_state
 import settings
 import speechgenerator
+import where_am_I
 
 class Script:
     """The specific focus tracking scripts for applications.
@@ -82,6 +83,7 @@ class Script:
 
         self.brailleGenerator = self.getBrailleGenerator()
         self.speechGenerator = self.getSpeechGenerator()
+        self.whereAmI = self.getWhereAmI()
         self.voices = settings.voices
 
         self.flatReviewContextClass = flat_review.Context
@@ -174,6 +176,11 @@ class Script:
         """
         return speechgenerator.SpeechGenerator(self)
 
+    def getWhereAmI(self):
+        """Returns the "where am I" class for this script.
+        """
+        return where_am_I.WhereAmI(self)
+
     # [[[WDW - There is a circular reference going on somewhere (see
     # bug 333168).  In the presence of this reference, the existence
     # of a __del__ method prevents the garbage collector from
