@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: Evolution.py 2174 2007-03-14 19:33:59Z richb $"
-__version__   = "$Revision: 2174 $"
-__date__      = "$Date: 2007-03-14 15:33:59 -0400 (Wed, 14 Mar 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: Evolution.py 2302 2007-04-19 17:29:45Z joanied $"
+__version__   = "$Revision: 2302 $"
+__date__      = "$Date: 2007-04-19 13:29:45 -0400 (Thu, 19 Apr 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import orca.debug as debug
@@ -32,13 +32,58 @@ import orca.input_event as input_event
 import orca.keybindings as keybindings
 import orca.rolenames as rolenames
 import orca.braille as braille
+import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.speech as speech
+import orca.speechserver as speechserver
 import orca.settings as settings
 import orca.chnames as chnames
+import orca.where_am_I as where_am_I
 
 from orca.orca_i18n import _ # for gettext support
 
+class WhereAmI(where_am_I.WhereAmI):
+
+    def __init__(self, script):
+        """Create a new WhereAmI that will be used to speak information
+        about the current object of interest.
+        """
+
+        where_am_I.WhereAmI.__init__(self, script)
+
+    def _getTableCell(self, obj):
+        """Get the speech utterances for a single table cell.
+        """
+
+        # Don't speak check box cells that area not checked.
+        notChecked = False
+        action = obj.action
+        if action:
+            for i in range(0, action.nActions):
+                if action.getName(i) == "toggle":
+                    obj.role = rolenames.ROLE_CHECK_BOX
+                    if not obj.state.count(atspi.Accessibility.STATE_CHECKED):
+                        notChecked = True
+                    obj.role = rolenames.ROLE_TABLE_CELL
+                    break
+
+        if notChecked:
+            return ""
+
+        descendant = self._script.getRealActiveDescendant(obj)
+        text = self._script.getDisplayedText(descendant)
+
+        # For Evolution mail header list.
+        if text == "Status":
+            # Translators: this in reference to an e-mail message status of
+            # having been read or unread.
+            #
+            text = _("Read")
+
+        debug.println(self._debugLevel, "cell=<%s>" % text)
+
+        return text
+
 ########################################################################
 #                                                                      #
 # The Evolution script class.                                          #
@@ -86,18 +131,37 @@ class Script(default.Script):
         # to Orca for Speech and Braille output.
 
         rolenames.ROLE_CALENDAR_VIEW = "Calendar View"
-        rolenames.rolenames[rolenames.ROLE_CALENDAR_VIEW] = \
-            rolenames.Rolename(rolenames.ROLE_CALENDAR_VIEW,
-                               _("calv"),
-                               _("CalendarView"),
-                               _("calendar view"))
+        rolenames.rolenames[rolenames.ROLE_CALENDAR_VIEW] = rolenames.Rolename(
+            rolenames.ROLE_CALENDAR_VIEW,
+            # Translators: short braille for the rolename of a calendar view.
+            #
+            _("calv"),
+            # Translators: long braille for the rolename of a calendar view.
+            #
+            _("CalendarView"),
+            # Translators: spoken words for the rolename of a calendar view.
+            #
+            _("calendar view"))
 
         rolenames.ROLE_CALENDAR_EVENT = "Calendar Event"
         rolenames.rolenames[rolenames.ROLE_CALENDAR_EVENT] = \
-            rolenames.Rolename(rolenames.ROLE_CALENDAR_EVENT,
-                               _("cale"),
-                               _("CalendarEvent"),
-                               _("calendar event"))
+            rolenames.Rolename(
+            rolenames.ROLE_CALENDAR_EVENT,
+            # Translators: short braille for the rolename of a calendar event.
+            #
+            _("cale"),
+            # Translators: long braille for the rolename of a calendar event.
+            #
+            _("CalendarEvent"),
+            # Translators: spoken words for the rolename of a calendar event.
+            #
+            _("calendar event"))
+
+    def getWhereAmI(self):
+        """Returns the "where am I" class for this script.
+        """
+
+        return WhereAmI(self)
 
     def setupInputEventHandlers(self):
         """Defines InputEventHandler fields for this script that can be
@@ -115,6 +179,10 @@ class Script(default.Script):
         self.inputEventHandlers["toggleReadMailHandler"] = \
             input_event.InputEventHandler(
                 Script.toggleReadMail,
+                # Translators: this tells Orca to act like 'biff', or let
+                # the user know when new mail has arrived, even if Evolution
+                # doesn't have focus.
+                #
                 _("Toggle whether we present new mail if we are not the active script."))
 
     def getKeyBindings(self):
@@ -145,9 +213,17 @@ class Script(default.Script):
 
         debug.println(self.debugLevel, "Evolution.toggleReadMail.")
 
+        # Translators: this tells Orca to act like 'biff', or let
+        # the user know when new mail has arrived, even if Evolution
+        # doesn't have focus.
+        #
         line = _("present new mail if this script is not active.")
         self.presentIfInactive = not self.presentIfInactive
         if not self.presentIfInactive:
+            # Translators: this tells Orca to act like 'biff', or let
+            # the user know when new mail has arrived, even if Evolution
+            # doesn't have focus.
+            #
             line = _("do not present new mail if this script is not active.")
 
         speech.speak(line)
@@ -195,7 +271,10 @@ class Script(default.Script):
                         # done so.
                         #
                         if text and not self.setupLabels.has_key(label):
-                            speech.speak(text + _(" screen"), None, False)
+                            # Translators: this is the name of a setup
+                            # assistant window/screen in Evolution.
+                            #
+                            speech.speak(_("%s screen") % text, None, False)
                             self.setupLabels[label] = True
 
                             # If the locus of focus is a push button that's
@@ -224,6 +303,10 @@ class Script(default.Script):
                 # starts with "Welcome". For the last screen, it starts
                 # with "Congratulations". Speak those too.
                 #
+                # Translators: we regret having to do this, but the
+                # translated string here has to match what the translated
+                # string is for Evolution.
+                #
                 if text.startswith(_("Please")) or \
                     text.startswith(_("Welcome")) or \
                     text.startswith(_("Congratulations")):
@@ -289,25 +372,120 @@ class Script(default.Script):
 
         return hrs + ' ' + mins + ' ' + suffix
 
-    def readTextLines(self):
-        """This an iterator that produces elements of the form:
-        [SayAllContext, acss], where SayAllContext has the text to be
-        spoken and acss is an ACSS instance for speaking the text.  We
-        do this because of the way Evolution lays out its messages:
-        each paragraph tends to be in its own panel, each of which is
+    def textLines(self, obj):
+        """Creates a generator that can be used to iterate over each line
+        of a text object, starting at the caret offset.
+
+        We have to subclass this because Evolution lays out its messages
+        such that each paragraph is in its own panel, each of which is
         in a higher level panel.  So, we just traverse through the
         children.
+
+        Arguments:
+        - obj: an Accessible that has a text specialization
+
+        Returns an iterator that produces elements of the form:
+        [SayAllContext, acss], where SayAllContext has the text to be
+        spoken and acss is an ACSS instance for speaking the text.
         """
-        panel = orca_state.locusOfFocus.parent
-        htmlPanel = orca_state.locusOfFocus.parent.parent
+
+        if not obj:
+            return
+
+        text = obj.text
+        if not text:
+            return
+
+        panel = obj.parent
+        htmlPanel = panel.parent
         startIndex = panel.index
-        for i in range(startIndex, htmlPanel.childCount):
+        i = startIndex
+        total = htmlPanel.childCount
+        textObjs = []
+        startOffset = obj.text.caretOffset
+        offset = obj.text.caretOffset
+        string = ""
+        done = False
+
+        # Determine the correct "say all by" mode to use.
+        #
+        if settings.sayAllStyle == settings.SAYALL_STYLE_SENTENCE:
+            mode = atspi.Accessibility.TEXT_BOUNDARY_SENTENCE_END
+        elif settings.sayAllStyle == settings.SAYALL_STYLE_LINE:
+            mode = atspi.Accessibility.TEXT_BOUNDARY_LINE_START
+        else:
+            mode = atspi.Accessibility.TEXT_BOUNDARY_LINE_START
+
+        while not done:
             accPanel = htmlPanel.accessible.getChildAtIndex(i)
             panel = atspi.Accessible.makeAccessible(accPanel)
             accTextObj = panel.accessible.getChildAtIndex(0)
             textObj = atspi.Accessible.makeAccessible(accTextObj)
-            for [context, acss] in self.textLines(textObj):
-                yield [context, acss]
+            text = textObj.text
+            if not text:
+                return
+            textObjs.append(textObj)
+            length = text.characterCount
+
+            while offset <= length:
+                [mystr, start, end] = textObj.text.getTextAtOffset(offset,
+                                                                   mode)
+
+                if len(mystr) != 0:
+                    string += mystr
+
+                if mode == atspi.Accessibility.TEXT_BOUNDARY_LINE_START or \
+                   len(mystr) == 0 or mystr[len(mystr)-1] in '.?!':
+                    endOffset = end
+
+                    string = self.adjustForRepeats(string)
+                    if string.isupper():
+                        voice = settings.voices[settings.UPPERCASE_VOICE]
+                    else:
+                        voice = settings.voices[settings.DEFAULT_VOICE]
+
+                    if not textObjs:
+                        textObjs.append(textObj)
+                    yield [speechserver.SayAllContext(textObjs, string,
+                                                      startOffset, endOffset),
+                           voice]
+                    textObjs = []
+                    string = ""
+                    startOffset = endOffset
+
+                if len(mystr) == 0 or end == length:
+                    break
+                else:
+                    offset = end
+
+            offset = 0
+            i += 1
+            if i == total:
+                done = True
+
+    def __sayAllProgressCallback(self, context, type):
+        """Provide feedback during the sayAll operation.
+        """
+
+        if type == speechserver.SayAllContext.PROGRESS:
+            #print "PROGRESS", context.utterance, context.currentOffset
+            pass
+        elif type == speechserver.SayAllContext.INTERRUPTED:
+            #print "INTERRUPTED", context.utterance, context.currentOffset
+            offset = context.currentOffset
+            for i in range(0, len(context.obj)):
+                obj = context.obj[i]
+                charCount = obj.text.characterCount
+                if offset > charCount:
+                    offset -= charCount
+                else:
+                    obj.text.setCaretOffset(offset)
+                    break
+        elif type == speechserver.SayAllContext.COMPLETED:
+            #print "COMPLETED", context.utterance, context.currentOffset
+            obj = context.obj[len(context.obj)-1]
+            obj.text.setCaretOffset(context.currentOffset)
+            orca.setLocusOfFocus(None, obj, False)
 
     def sayAll(self, inputEvent):
         """Speak all the text associated with the text object that has
@@ -322,7 +500,7 @@ class Script(default.Script):
 
         debug.println(self.debugLevel, "evolution.sayAll.")
         if orca_state.locusOfFocus and orca_state.locusOfFocus.text:
-            speech.sayAll(self.readTextLines(),
+            speech.sayAll(self.textLines(orca_state.locusOfFocus),
                           self.__sayAllProgressCallback)
         else:
             default.Script.sayAll(self, inputEvent)
@@ -388,17 +566,20 @@ class Script(default.Script):
             if settings.enableSpeechIndentation:
                 self.speakTextIndentation(event.source, string)
             line = self.adjustForRepeats(string)
-                
+
             if self.speakNewLine(event.source):
                 speech.speak(chnames.getCharacterName("\n"), None, False)
- 
+
             if self.speakBlankLine(event.source):
+                # Translators: "blank" is a short word to mean the
+                # user has navigated to an empty line.
+                #
                 speech.speak(_("blank"), None, False)
             else:
                 speech.speak(line, None, False)
 
             return
-        
+
 
         # 2) Mail view: current message pane: "standard" mail header lines.
         #
@@ -493,15 +674,23 @@ class Script(default.Script):
             column = parent.table.getColumnAtIndex(event.source.index)
 
             # This is an indication of whether we should speak all the table
-            # cells (the user has moved focus up or down the list), or just
-            # the current one (focus has moved left or right in the same row).
-            # If we at the start or the end of the message header list and
-            # the row and column haven't changed, then speak all the table
-            # cells.
+            # cells (the user has moved focus up or down the list, or just
+            # deleted a message), or just the current one (focus has moved
+            # left or right in the same row). If we at the start or the end
+            # of the message header list and the row and column haven't 
+            # changed, then speak all the table cells.
+            #
+            justDeleted = False
+            if isinstance(orca_state.lastInputEvent,
+                          input_event.KeyboardEvent):
+                string = orca_state.lastInputEvent.event_string
+                if string == "Delete":
+                    justDeleted = True
 
             speakAll = (self.lastMessageRow != row) or \
                        ((row == 0 or row == parent.table.nRows-1) and \
-                        self.lastMessageColumn == column)
+                        self.lastMessageColumn == column) or \
+                       justDeleted
 
             savedBrailleVerbosityLevel = settings.brailleVerbosityLevel
             savedSpeechVerbosityLevel = settings.speechVerbosityLevel
@@ -557,6 +746,11 @@ class Script(default.Script):
                                 checked = cell.state.count( \
                                     atspi.Accessibility.STATE_CHECKED)
                                 if speakAll:
+                                    # Translators: this is the name of the
+                                    # status column header in the message
+                                    # list in Evolution.  The name needs to
+                                    # match what Evolution is using.
+                                    #
                                     if header.name == _("Status"):
                                         toRead = not checked
                                         break
@@ -604,11 +798,25 @@ class Script(default.Script):
                         [cellRegions, focusedRegion] = \
                                            brailleGen.getBrailleRegions(cell)
 
+                        # Translators: this is the name of the
+                        # status column header in the message
+                        # list in Evolution.  The name needs to
+                        # match what Evolution is using.
+                        #
                         if header.name == _("Status"):
+                            # Translators: we present this to the user to
+                            # indicate that an email message has not been
+                            # marked as having been read.
+                            #
                             text = _("unread")
                             utterances = [ text ]
                             brailleRegions.append(braille.Region(text))
                             brailleRegions.append(braille.Region(" "))
+                        # Translators: this is the name of the
+                        # attachment column header in the message
+                        # list in Evolution.  The name needs to
+                        # match what Evolution is using.
+                        #
                         elif header.name == _("Attachment"):
                             text = header.name
                             utterances = [ text ]
@@ -770,6 +978,9 @@ class Script(default.Script):
                 brailleRegions.append(braille.Region(startTime))
                 speech.speak(startTime)
 
+                # Translators: this means there are no scheduled entries
+                # in the calendar.
+                #
                 utterance = _("No appointments")
                 speech.speak(utterance)
                 brailleRegions.append(braille.Region(utterance))
@@ -844,6 +1055,10 @@ class Script(default.Script):
                           + "attachment dialog: unlabelled button.")
 
             brailleRegions = []
+            # Translators: this is the unlabelled arrow button near the
+            # top of the mail view Insert Attachment dialog in Evolution.
+            # We give it a name.
+            #
             utterance = _("Directories button")
             speech.speak(utterance)
             brailleRegions.append(braille.Region(utterance))
@@ -872,15 +1087,18 @@ class Script(default.Script):
                           + "compose window: message area.")
 
             self.message_panel = event.source.parent.parent
-            
+
             if self.speakNewLine(event.source):
                 speech.speak(chnames.getCharacterName("\n"), None, False)
 
 
             if self.speakBlankLine(event.source):
-                 speech.speak(_("blank"), None, False)
+                # Translators: "blank" is a short word to mean the
+                # user has navigated to an empty line.
+                #
+                speech.speak(_("blank"), None, False)
+
 
-                
         # 9) Spell Checking Dialog
         #
         # This works in conjunction with code in section 8). Check to see if
@@ -990,6 +1208,12 @@ class Script(default.Script):
 
         obj = event.source.parent
         while obj and obj.role != rolenames.ROLE_APPLICATION:
+            # Translators: this is the ending of the name of the
+            # Evolution Setup Assistant window.  The translated
+            # form has to match what Evolution is using.  We hate
+            # keying off stuff like this, but we're forced to do
+            # so in this case.
+            #
             if obj.role == rolenames.ROLE_FRAME and \
                 obj.name.endswith(_("Assistant")):
                 debug.println(self.debugLevel,
@@ -1023,7 +1247,7 @@ class Script(default.Script):
         if not (orca_state.lastInputEvent and \
                 orca_state.lastInputEvent.__dict__.has_key("event_string")):
             return False
-        
+
         lastKey = orca_state.lastInputEvent.event_string
         if lastKey != "Left" and lastKey != "Right":
             return False
@@ -1031,14 +1255,14 @@ class Script(default.Script):
         # Was a control key pressed?
         mods = orca_state.lastInputEvent.modifiers
         isControlKey = mods & (1 << atspi.Accessibility.MODIFIER_CONTROL)
-        
+
         # Get the line containing the caret
         caretOffset = text.caretOffset
         line = text.getTextAtOffset(caretOffset, \
             atspi.Accessibility.TEXT_BOUNDARY_LINE_START)
         lineStart = line[1]
         lineEnd = line[2]
-        
+
         if isControlKey:  # control-right-arrow or control-left-arrow
 
             # Get the word containing the caret.
@@ -1046,20 +1270,20 @@ class Script(default.Script):
                 atspi.Accessibility.TEXT_BOUNDARY_WORD_START)
             wordStart = word[1]
             wordEnd = word[2]
-            
+
             if lastKey == "Right":
                 if wordStart == lineStart:
                     return True
-            else: 
+            else:
                 if wordEnd == lineEnd:
                     return True
-                
+
         else:  # right arrow or left arrow
-            
+
             if lastKey == "Right":
                 if caretOffset == lineStart:
                     return True
-            else: 
+            else:
                 if caretOffset == lineEnd:
                     return True
 
@@ -1068,8 +1292,8 @@ class Script(default.Script):
         """Returns True if a blank line should be spoken.
         Otherwise, returns False.
         """
-        
-        # Get the the AccessibleText interrface. 
+
+        # Get the the AccessibleText interrface.
         text = obj.text
         if not text:
             return False
@@ -1088,7 +1312,7 @@ class Script(default.Script):
         else:
             return False
 
-        
+
     def onStateChanged(self, event):
         """Called whenever an object's state changes.  We are only
         interested in "object:state-changed:showing" events for any
@@ -1108,6 +1332,12 @@ class Script(default.Script):
             #
             obj = event.source.parent
             while obj and obj.role != rolenames.ROLE_APPLICATION:
+                # Translators: this is the ending of the name of the
+                # Evolution Setup Assistant window.  The translated
+                # form has to match what Evolution is using.  We hate
+                # keying off stuff like this, but we're forced to do
+                # so in this case.
+                #
                 if obj.role == rolenames.ROLE_FRAME and \
                     obj.name.endswith(_("Assistant")):
                     debug.println(self.debugLevel,
@@ -1136,6 +1366,42 @@ class Script(default.Script):
         #
         default.Script.onStateChanged(self, event)
 
+    def onFocus(self, event):
+        """Called whenever an object gets focus.  
+
+        Arguments:
+        - event: the Event
+        """
+
+        # When a message is deleted from within the table of messages, we get
+        # two focus events:  One for the index of the new message prior to
+        # deletion and one for the index of the new message after deletion.
+        # This causes us to speak the message after the one that gets focus
+        # prior to speaking the actual message that gets focus. 
+        # See bug #347964.
+        # 
+        if isinstance(orca_state.lastInputEvent,
+                      input_event.KeyboardEvent):
+            string = orca_state.lastInputEvent.event_string
+            if string == "Delete":
+                rolesList = [rolenames.ROLE_TABLE_CELL, \
+                             rolenames.ROLE_TREE_TABLE, \
+                             rolenames.ROLE_UNKNOWN, \
+                             rolenames.ROLE_SCROLL_PANE]
+                oldLocusOfFocus = orca_state.locusOfFocus
+                if self.isDesiredFocusedItem(event.source, rolesList) and \
+                   self.isDesiredFocusedItem(oldLocusOfFocus, rolesList):
+                    parent = event.source.parent
+                    newRow = parent.table.getRowAtIndex(event.source.index)
+                    oldRow = parent.table.getRowAtIndex(oldLocusOfFocus.index)
+                    nRows = parent.table.nRows
+                    if (newRow != oldRow) and (oldRow != nRows):
+                        return
+
+        # For everything else, pass the event onto the parent class
+        # to be handled in the default way.
+        #
+        default.Script.onFocus(self, event)
 
 # Values used to construct a time string for calendar appointments.
 #
