@@ -21,9 +21,9 @@
 of manipulating text - both the user and the system put text into the
 system and we try to determine which was which and why."""
 
-__id__        = "$Id: gnome-terminal.py 1925 2007-01-15 02:32:55Z wwalker $"
-__version__   = "$Revision: 1925 $"
-__date__      = "$Date: 2007-01-14 21:32:55 -0500 (Sun, 14 Jan 2007) $"
+__id__        = "$Id: gnome-terminal.py 2160 2007-03-12 17:18:51Z richb $"
+__version__   = "$Revision: 2160 $"
+__date__      = "$Date: 2007-03-12 13:18:51 -0400 (Mon, 12 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -31,7 +31,6 @@ import orca.atspi as atspi
 import orca.debug as debug
 import orca.default as default
 import orca.input_event as input_event
-import orca.util as util
 import orca.orca_state as orca_state
 import orca.rolenames as rolenames
 import orca.settings as settings
@@ -67,7 +66,7 @@ class Script(default.Script):
     #
     #    # Now we find the focused object and set the locus of focus to it.
     #    #
-    #    obj = util.findFocusedObject(self.app)
+    #    obj = self.findFocusedObject(self.app)
     #    if obj:
     #        orca.setLocusOfFocus(event, obj)
     #    else:
@@ -147,46 +146,45 @@ class Script(default.Script):
         # We'll let our super class handle "Delete".  We'll handle Ctrl+D.
         #
 
-        if not orca_state.lastInputEvent or \
-            not isinstance(orca_state.lastInputEvent,
-                           input_event.KeyboardEvent):
+        if not orca_state.lastInputEvent:
             return
 
-        keyString = orca_state.lastInputEvent.event_string
-
-        controlPressed = orca_state.lastInputEvent.modifiers \
-                         & (1 << atspi.Accessibility.MODIFIER_CONTROL)
-
-        if (keyString == "Delete") or (keyString == "BackSpace"):
-            return
-        elif (keyString == "D") and controlPressed:
-            text = text.decode("UTF-8")[0].decode("UTF-8")
-
-        # If the last input event was a keyboard event, check to see if
-        # the text for this event matches what the user typed. If it does,
-        # then don't speak it.
-        #
-        # Note that the text widgets sometimes compress their events,
-        # thus we might get a longer string from a single text inserted
-        # event, while we also get individual keyboard events for the
-        # characters used to type the string.  This is ugly.  We attempt
-        # to handle it here by only echoing text if we think it was the
-        # result of a command (e.g., a paste operation).
-        #
-        # Note that we have to special case the space character as it
-        # comes across as "space" in the keyboard event and " " in the
-        # text event.
-        #
-        # For terminal, Return usually ends up in more text from the
-        # system, which we want to hear.  Tab is also often used for
-        # command line completion, so we want to hear that, too.
-        #
-        # Finally, if we missed some command and the system is giving
-        # us a string typically longer than what the length of a
-        # compressed string is (we choose 5 here), then output that.
-        #
         matchFound = False
+        speakThis = False
         if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
+            keyString = orca_state.lastInputEvent.event_string
+
+            controlPressed = orca_state.lastInputEvent.modifiers \
+                             & (1 << atspi.Accessibility.MODIFIER_CONTROL)
+
+            if (keyString == "Delete") or (keyString == "BackSpace"):
+                return
+            elif (keyString == "D") and controlPressed:
+                text = text.decode("UTF-8")[0].decode("UTF-8")
+
+            # If the last input event was a keyboard event, check to see if
+            # the text for this event matches what the user typed. If it does,
+            # then don't speak it.
+            #
+            # Note that the text widgets sometimes compress their events,
+            # thus we might get a longer string from a single text inserted
+            # event, while we also get individual keyboard events for the
+            # characters used to type the string.  This is ugly.  We attempt
+            # to handle it here by only echoing text if we think it was the
+            # result of a command (e.g., a paste operation).
+            #
+            # Note that we have to special case the space character as it
+            # comes across as "space" in the keyboard event and " " in the
+            # text event.
+            #
+            # For terminal, Return usually ends up in more text from the
+            # system, which we want to hear.  Tab is also often used for
+            # command line completion, so we want to hear that, too.
+            #
+            # Finally, if we missed some command and the system is giving
+            # us a string typically longer than what the length of a
+            # compressed string is (we choose 5 here), then output that.
+            #
             wasCommand = orca_state.lastInputEvent.modifiers \
                          & (1 << atspi.Accessibility.MODIFIER_CONTROL \
                             | 1 << atspi.Accessibility.MODIFIER_ALT \
@@ -201,12 +199,20 @@ class Script(default.Script):
                 matchFound = True
                 pass
             elif wasCommand or (len(text) > 5):
-                if text.isupper():
-                    speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
-                else:
-                    speech.speak(text)
+                speakThis = True
+
+        elif isinstance(orca_state.lastInputEvent, \
+                        input_event.MouseButtonEvent) and \
+             orca_state.lastInputEvent.button == "2":
+            speakThis = True
+
+        if speakThis:
+            if text.isupper():
+                speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
+            else:
+                speech.speak(text)
 
         if settings.enableEchoByWord \
-           and util.isWordDelimiter(text.decode("UTF-8")[-1:]):
+           and self.isWordDelimiter(text.decode("UTF-8")[-1:]):
             if matchFound:
                 self.echoPreviousWord(event.source)
