@@ -19,27 +19,19 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 2207 2007-03-27 16:48:44Z richb $"
-__version__   = "$Revision: 2207 $"
-__date__      = "$Date: 2007-03-27 12:48:44 -0400 (Tue, 27 Mar 2007) $"
+__id__        = "$Id: where_am_I.py 2296 2007-04-18 16:45:21Z richb $"
+__version__   = "$Revision: 2296 $"
+__date__      = "$Date: 2007-04-18 12:45:21 -0400 (Wed, 18 Apr 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import string
-
 import atspi
-import chnames
 import debug
-import default
-import input_event
-import orca_prefs
 import orca_state
 import rolenames
 import settings
 import speech
-import speechserver
-import Accessibility
-import math
+
 from orca_i18n import _ # for gettext support
 
 class WhereAmI:
@@ -51,11 +43,10 @@ class WhereAmI:
 
         self._script = script
         self._debugLevel = debug.LEVEL_FINEST
-        self._appName = None
         self._statusBar = None
         self._lastAttributeString = ""
 
-    def whereAmI(self, obj, context, doubleClick, orcaKey):
+    def whereAmI(self, obj, doubleClick, orcaKey):
         """Speaks information about the current object of interest, including
         the object itself, which window it is in, which application, which
         workspace, etc.
@@ -67,12 +58,11 @@ class WhereAmI:
         whether it has keyboard focus or not.
         """
 
-        if (not obj) or (not context):
+        if (not obj):
             return False
 
         debug.println(self._debugLevel,
             "whereAmI: \
-           \n  context= %s \
            \n  label=%s \
            \n  name=%s \
            \n  role=%s \
@@ -82,8 +72,7 @@ class WhereAmI:
            \n  parent role=%s \
            \n  double-click=%s \
            \n  orca-key=%s" % \
-            (context,
-             self._getObjLabel(obj),
+            (self._getObjLabel(obj),
              self._getObjName(obj),
              obj.role,
              self._script.getAcceleratorAndShortcut(obj),
@@ -93,19 +82,10 @@ class WhereAmI:
              doubleClick,
              orcaKey))
 
-        self._appName = context[0]
         role = obj.role
 
         if orcaKey:
-            # Handle the Orca modifier key being pressed.
-            if self._getAppName() == "soffice.bin":
-                top = self._script.getTopLevel(obj)
-                if top and top.name.endswith(" Calc"):
-                    self._handleCalcOrcaKey(obj, doubleClick)
-                else:
-                    self._handleOrcaKey(obj, doubleClick)
-            else:
-                self._handleOrcaKey(obj, doubleClick)
+            self._processOrcaKey(obj, doubleClick)
 
         elif role == rolenames.ROLE_CHECK_BOX:
             self._speakCheckBox(obj, doubleClick)
@@ -141,21 +121,21 @@ class WhereAmI:
             self._speakText(obj, doubleClick)
 
         elif role == rolenames.ROLE_TABLE_CELL:
-            if self._getAppName() == "soffice.bin":
-                self._speakCalcTableCell(obj, doubleClick)
-            else:
-                self._speakTableCell(obj, doubleClick)
+            self._speakTableCell(obj, doubleClick)
 
         elif role == rolenames.ROLE_PARAGRAPH:
             self._speakParagraph(obj, doubleClick)
 
+        else:
+            self._speakGenericObject(obj, doubleClick)
+
         return True
 
-    def _getAppName(self):
-        """Returns the application name.
+    def _processOrcaKey(self, obj, doubleClick):
+        """Test to see if the Orca modifier key has been pressed.
         """
 
-        return self._appName
+        self._handleOrcaKey(obj, doubleClick)
 
     def _speakCheckBox(self, obj, doubleClick):
         """Checkboxes present the following information
@@ -170,20 +150,24 @@ class WhereAmI:
         text = self._getObjLabelAndName(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+            # Translators: this represents the state of a checkbox.
+            #
             text = _("checked")
         else:
+            # Translators: this represents the state of a checkbox.
+            #
             text = _("not checked")
-            utterances.append(text)
-
-        text = _("%s") % self._getObjMnemonic(obj)
         utterances.append(text)
 
-        debug.println(self._debugLevel, "check box utterances=%s" % \
-                      utterances)
+        text = self._getObjMnemonic(obj)
+        utterances.append(text)
+
+        debug.println(self._debugLevel, "check box utterances=%s" \
+                      % utterances)
         speech.speakUtterances(utterances)
 
     def _speakRadioButton(self, obj, doubleClick):
@@ -199,30 +183,34 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % self._getGroupLabel(obj)
+        text = self._getGroupLabel(obj)
         utterances.append(text)
 
         if doubleClick:
-            text = _("%s") % self._getPositionInGroup(obj)
+            text = self._getPositionInGroup(obj)
             utterances.append(text)
 
-        text = _("%s") % self._getObjLabelAndName(obj)
+        text = self._getObjLabelAndName(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+            # Translators: this represents the state of a checkbox.
+            #
             text = _("checked")
         else:
+            # Translators: this represents the state of a checkbox.
+            #
             text = _("not checked")
         utterances.append(text)
 
         if not doubleClick:
-            text = _("%s") % self._getPositionInGroup(obj)
+            text = self._getPositionInGroup(obj)
             utterances.append(text)
 
-        text = _("%s") % self._getObjMnemonic(obj)
+        text = self._getObjMnemonic(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "radio button utterances=%s" % \
@@ -241,28 +229,28 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % self._getObjLabel(obj)
+        text = self._getObjLabel(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         if doubleClick:
             # child(0) is the popup list
-            name = _("%s") % self._getObjName(obj)
-            text = _("%s") % self._getPositionInList(obj.child(0), name)
+            name = self._getObjName(obj)
+            text = self._getPositionInList(obj.child(0), name)
             utterances.append(text)
 
             utterances.append(name)
         else:
-            name = _("%s") % self._getObjName(obj)
+            name = self._getObjName(obj)
             utterances.append(name)
 
             # child(0) is the popup list
-            text = _("%s") % self._getPositionInList(obj.child(0), name)
+            text = self._getPositionInList(obj.child(0), name)
             utterances.append(text)
 
-        text = _("%s") % self._getObjMnemonic(obj)
+        text = self._getObjMnemonic(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "combo box utterances=%s" % \
@@ -280,10 +268,10 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % self._getObjLabelAndName(obj)
+        text = self._getObjLabelAndName(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         value = obj.value
@@ -291,7 +279,7 @@ class WhereAmI:
             text = "%.1f" % value.currentValue
             utterances.append(text)
 
-        text = _("%s") % self._getObjMnemonic(obj)
+        text = self._getObjMnemonic(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "spin button utterances=%s" % \
@@ -308,13 +296,13 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % self._getObjLabelAndName(obj)
+        text = self._getObjLabelAndName(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
-        text = _("%s") % self._getObjMnemonic(obj)
+        text = self._getObjMnemonic(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "push button utterances=%s" % \
@@ -333,17 +321,19 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % self._getObjLabel(obj)
+        text = self._getObjLabel(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         values = self._getSliderValues(obj)
-        utterances.append(_("%s") % values[0])
+        utterances.append(values[0])
+        # Translators: this is the percentage value of a slider.
+        #
         utterances.append(_("%s percent") % values[1])
 
-        text = _("%s") % self._getObjMnemonic(obj)
+        text = self._getObjMnemonic(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "slider utterances=%s" % \
@@ -363,31 +353,31 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % self._getObjLabelAndName(obj.parent)
+        text = self._getObjLabelAndName(obj.parent)
         utterances.append(text)
 
         if doubleClick:
             # parent is the page tab list
-            name = _("%s") % self._getObjName(obj)
-            text = _("%s") % self._getPositionInList(obj.parent, name)
+            name = self._getObjName(obj)
+            text = self._getPositionInList(obj.parent, name)
             utterances.append(text)
 
-        text = _("%s") % self._getObjLabelAndName(obj)
+        text = self._getObjLabelAndName(obj)
         utterances.append(text)
 
-        text = _("%s") % self._getObjAccelerator(obj)
+        text = self._getObjAccelerator(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         if not doubleClick:
             # parent is the page tab list
-            name = _("%s") % self._getObjName(obj)
-            text = _("%s") % self._getPositionInList(obj.parent, name)
+            name = self._getObjName(obj)
+            text = self._getPositionInList(obj.parent, name)
             utterances.append(text)
 
-        text = _("%s") % self._getObjShortcut(obj)
+        text = self._getObjShortcut(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "menu item utterances=%s" % \
@@ -405,25 +395,29 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         if doubleClick:
+            # Translators: "page" is the word for a page tab in a tab list.
+            #
             text = _("%s page") % self._getObjLabelAndName(obj)
             utterances.append(text)
 
-            name = _("%s") % self._getObjName(obj)
-            text = _("%s") % self._getPositionInList(obj.parent, name)
+            name = self._getObjName(obj)
+            text = self._getPositionInList(obj.parent, name)
             utterances.append(text)
         else:
-            name = _("%s") % self._getObjName(obj)
-            text = _("%s") % self._getPositionInList(obj.parent, name)
+            name = self._getObjName(obj)
+            text = self._getPositionInList(obj.parent, name)
             utterances.append(text)
 
+            # Translators: "page" is the word for a page tab in a tab list.
+            #
             text = _("%s page") % self._getObjLabelAndName(obj)
             utterances.append(text)
 
-        text = _("%s") % self._getObjMnemonic(obj)
+        text = self._getObjMnemonic(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "page utterances=%s" % \
@@ -448,10 +442,10 @@ class WhereAmI:
         """
 
         utterances = []
-        text = _("%s") % self._getObjLabel(obj)
+        text = self._getObjLabel(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
 
         [textContents, startOffset, endOffset, selected] = \
@@ -459,12 +453,12 @@ class WhereAmI:
         if doubleClick:
             # Speak character attributes.
             textContents = \
-                self._insertAttributes(obj, startOffset, 
+                self._insertAttributes(obj, startOffset,
                                        endOffset, textContents)
             savedStyle = settings.verbalizePunctuationStyle
             settings.verbalizePunctuationStyle = settings.PUNCTUATION_STYLE_SOME
 
-        text = _("%s") % textContents
+        text = textContents
         utterances.append(text)
         debug.println(self._debugLevel, "first text utterances=%s" % \
                       utterances)
@@ -475,47 +469,16 @@ class WhereAmI:
 
         utterances = []
         if selected:
-            text = _("%s") % "selected"
+            text = _("selected")
             utterances.append(text)
 
-        text = _("%s") % self._getObjMnemonic(obj)
+        text = self._getObjMnemonic(obj)
         utterances.append(text)
 
         debug.println(self._debugLevel, "text utterances=%s" % \
                       utterances)
         speech.speakUtterances(utterances)
 
-    def _speakCalcTableCell(self, obj, doubleClick):
-        """Given the nature of OpenOffice Calc, Orca should override the
-        default KP_Enter behavior when the item with focus is a cell
-        within Calc. In this instance, the following information should
-        be spoken/displayed:
-
-        1. "Cell"
-        2. the cell coordinates
-        3. the cell contents:
-            A. if the cell is empty, "blank"
-            B. if the cell is being edited AND if some text within the cell
-            is selected, the selected text followed by "selected"
-            C. otherwise, the full contents of the cell
-        """
-
-        utterances = []
-        utterances.append(_("Cell"))
-
-        table = obj.parent.table
-        text = _("column %d") % (table.getColumnAtIndex(obj.index) + 1)
-        utterances.append(text)
-        text = _("row %d") % (table.getRowAtIndex(obj.index) + 1)
-        utterances.append(text)
-
-        text = obj.text.getText(0, -1)
-        utterances.append(text)
-
-        debug.println(self._debugLevel, "calc table cell utterances=%s" % \
-                      utterances)
-        speech.speakUtterances(utterances)
-
     def _speakTableCell(self, obj, doubleClick):
         """Tree Tables present the following information (an example is
         'Tree table, Mike Pedersen, item 8 of 10, tree level 2'):
@@ -536,10 +499,10 @@ class WhereAmI:
             obj = obj.parent
         parent = obj.parent
 
-        text = _("%s") % self._getObjLabel(obj)
+        text = self._getObjLabel(obj)
         utterances.append(text)
 
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
+        text = rolenames.getSpeechForRoleName(obj)
         utterances.append(text)
         debug.println(self._debugLevel, "first table cell utterances=%s" % \
                       utterances)
@@ -549,6 +512,8 @@ class WhereAmI:
         if doubleClick:
             table = parent.table
             row = table.getRowAtIndex(orca_state.locusOfFocus.index)
+            # Translators: this in reference to a row in a table.
+            #
             text = _("row %d of %d") % ((row+1), parent.table.nRows)
             utterances.append(text)
             speech.speakUtterances(utterances)
@@ -569,18 +534,31 @@ class WhereAmI:
                 return
 
             row = table.getRowAtIndex(orca_state.locusOfFocus.index)
+            # Translators: this in reference to a row in a table.
+            #
             text = _("row %d of %d") % ((row+1), parent.table.nRows)
             utterances.append(text)
 
         if obj.state.count(atspi.Accessibility.STATE_EXPANDABLE):
             if obj.state.count(atspi.Accessibility.STATE_EXPANDED):
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
                 text = _("expanded")
             else:
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
                 text = _("collapsed")
                 utterances.append(text)
 
         level = self._script.getNodeLevel(orca_state.locusOfFocus)
         if level >= 0:
+            # Translators: this represents the depth of a node in a tree
+            # view (i.e., how many ancestors a node has).
+            #
             utterances.append(_("tree level %d") % (level + 1))
 
         debug.println(self._debugLevel, "third table cell utterances=%s" % \
@@ -588,37 +566,22 @@ class WhereAmI:
         speech.speakUtterances(utterances)
 
     def _speakParagraph(self, obj, doubleClick):
-        """OpenOffice Calc cells have the role "paragraph" when
-        they are being edited.
+        """Speak a paragraph object.
         """
 
-        if self._getAppName() == "soffice.bin":
-            top = self._script.getTopLevel(obj)
-            if top and top.name.endswith(" Calc"):
-                self._speakCalc(obj, doubleClick)
+        self._speakText(obj, doubleClick)
 
-            elif top and top.name.endswith(" Writer"):
-                self._speakText(obj, doubleClick)
-
-    def _speakCalc(self, obj, doubleClick):
-        """Speak a OpenOffice Calc cell.
+    def _speakGenericObject(self, obj, doubleClick):
+        """Speak a generic object; one not specifically handled by
+        other methods.
         """
 
         utterances = []
-        utterances.append(_("Cell"))
-
-        # No way to get cell coordinates?
-
-        [textContents, startOffset, endOffset, selected] = \
-            self._getTextContents(obj, doubleClick)
-        text = _("%s") % textContents
+        text = self._getObjLabelAndName(obj)
         utterances.append(text)
-        if selected:
-            text = _("%s") % "selected"
-            utterances.append(text)
 
-        debug.println(self._debugLevel, "editable table cell utterances=%s" % \
-                      utterances)
+        text = rolenames.getSpeechForRoleName(obj)
+        utterances.append(text)
         speech.speakUtterances(utterances)
 
     def _getObjName(self, obj):
@@ -631,7 +594,7 @@ class WhereAmI:
             name = obj.description
 
         if name and name != "None":
-            text = _("%s") % name
+            text = name
         # debug.println(self._debugLevel, "%s name=<%s>" % (obj.role, text))
 
         return text
@@ -644,7 +607,7 @@ class WhereAmI:
         label = self._script.getDisplayedLabel(obj)
 
         if label and label != "None":
-            text = _("%s") % label
+            text = label
         # debug.println(self._debugLevel, "%s label=<%s>" % (obj.role, text))
 
         return text
@@ -656,9 +619,9 @@ class WhereAmI:
         name = self._getObjName(obj)
         label = self._getObjLabel(obj)
         if name != label:
-            text = _("%s %s") % (label, name)
+            text = label + " " + name
         else:
-            text = _("%s") % label
+            text = label
 
         if obj.text:
             [string, startOffset, endOffset] = obj.text.getTextAtOffset(0,
@@ -666,7 +629,7 @@ class WhereAmI:
 
             debug.println(self._debugLevel, "%s text=<%s>" % (obj.role, string))
 
-        return text
+        return text.strip()
 
     def _getGroupLabel(self, obj):
         """Returns the label for a group of components.
@@ -707,7 +670,7 @@ class WhereAmI:
 
         relations = obj.relations
         for relation in relations:
-            if relation.getRelationType() == Accessibility.RELATION_MEMBER_OF:
+            if relation.getRelationType() == atspi.Accessibility.RELATION_MEMBER_OF:
                 total = relation.getNTargets()
                 for i in range(0, total):
                     target = atspi.Accessible.makeAccessible( \
@@ -717,17 +680,12 @@ class WhereAmI:
                         break
 
         if position >= 0:
+            # Translators: this is an item in a list.
+            #
             text += _("item %d of %d") % (position, total)
 
         return text
 
-    def _getPositionInComboBox(self, obj, name):
-        """Returns the relative position of an object in a combo box.
-        """
-
-        # The only child of a combo box is the popup menu
-        return self._getPositionInList(obj.child(0), name)
-
     def _getPositionInList(self, obj, name):
         """Returns the relative position of an object in a list.
         """
@@ -752,6 +710,8 @@ class WhereAmI:
                 position = index
 
         if position >= 0:
+            # Translators: this is an item in a list.
+            #
             text = _("item %d of %d") % (position, total)
 
         return text
@@ -765,9 +725,9 @@ class WhereAmI:
 
         text = ""
         if not list[1]:
-            text = _("%s") % list[0]
+            text = list[0]
         else:
-            text = _("%s %s") % (list[0], list[1])
+            text = list[0] + " " +  list[1]
 
         return text
 
@@ -779,7 +739,7 @@ class WhereAmI:
 
         text = ""
         if list[0]:
-            text = _("%s") % list[0]
+            text = list[0]
 
         return text
 
@@ -791,7 +751,7 @@ class WhereAmI:
 
         text = ""
         if list[1]:
-            text = _("%s") % list[1]
+            text = list[1]
 
         return text
 
@@ -864,37 +824,10 @@ class WhereAmI:
         descendant = self._script.getRealActiveDescendant(obj)
         text = self._script.getDisplayedText(descendant)
 
-        # For Evolution mail header list.
-        if self._getAppName().startswith("evolution") and text == "Status":
-            text = _("Read")
-
         debug.println(self._debugLevel, "cell=<%s>" % text)
 
         return text
 
-    def _getCheckBox(self, obj):
-        """Returns utterences for a check box.
-        """
-
-        utterances = []
-
-        text = self._getObjLabelAndName(obj)
-        utterances.append(text)
-
-        text = _("%s") % rolenames.getSpeechForRoleName(obj)
-        utterances.append(text)
-
-        if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = _("checked")
-        else:
-            text = _("not checked")
-        utterances.append(text)
-
-        text = _("%s") % self._getObjMnemonic(obj)
-        utterances.append(text)
-
-        return utterances
-
     def _getTextContents(self, obj, doubleClick):
         """Returns utterences for text.
 
@@ -955,6 +888,9 @@ class WhereAmI:
 
                 if char[0] == "\n" and startOffset == caretOffset \
                        and settings.speakBlankLines:
+                    # Translators: "blank" is a short word to mean the
+                    # user has navigated to an empty line.
+                    #
                     textContents = (_("blank"))
 
         return [textContents, startOffset, endOffset, selected]
@@ -1006,6 +942,8 @@ class WhereAmI:
                         #
                         if key == "weight" and int(attribute) > 400:
                             attribStr += " "
+                            # Translators: bold as in the font sense.
+                            #
                             attribStr += _("bold")
 
                         elif key == "underline":
@@ -1090,51 +1028,16 @@ class WhereAmI:
                     self._speakStatusBar()
         else:
             if list[0]:
-                text = _("%s") % self._getObjLabelAndName(list[0])
+                text = self._getObjLabelAndName(list[0])
                 utterances.append(text)
             if list[1]:
-                text = _("%s") % self._getObjLabelAndName(list[1])
+                text = self._getObjLabelAndName(list[1])
                 utterances.append(text)
 
             debug.println(self._debugLevel, "titlebar utterances=%s" % \
                           utterances)
             speech.speakUtterances(utterances)
 
-    def _handleCalcOrcaKey(self, obj, doubleClick):
-        """Handle the Orca modifier key being pressed.
-
-        Calc-Specific Handling: If Insert+KP_Enter is pressed a single time
-        while focus is on a cell within OpenOffice Calc, Orca will speak the
-        following information:
-
-        1. The contents of the title bar of the application main window
-        2. The title of the current worksheet
-
-        Note that if the application with focus is Calc, but a cell does not
-        have focus, the default behavior should be used.
-        """
-
-        utterances = []
-
-        list = self._getCalcFrameAndSheet(obj)
-        if doubleClick:
-            if list[0]:
-                self._statusBar = None
-                self._getStatusBar(list[0])
-                if self._statusBar:
-                    self._speakCalcStatusBar()
-        else:
-            if list[0]:
-                text = _("%s") % self._getObjLabelAndName(list[0])
-                utterances.append(text)
-            if list[1]:
-                text = _("%s") % self._getObjLabelAndName(list[1])
-                utterances.append(text)
-
-            debug.println(self._debugLevel,
-                          "Calc titlebar and sheet utterances=%s" % utterances)
-            speech.speakUtterances(utterances)
-
     def _getFrameAndDialog(self, obj):
         """Returns the frame and (possibly) the dialog containing
         the object.
@@ -1155,25 +1058,6 @@ class WhereAmI:
 
         return list
 
-    def _getCalcFrameAndSheet(self, obj):
-        """Returns the Calc frame and sheet
-        """
-
-        list = [None, None]
-
-        parent = obj.parent
-        while parent and (parent.parent != parent):
-            # debug.println(self._debugLevel,
-            #               "_getCalcFrameAndSheet: parent=%s, %s" % \
-            #               (parent.role, self._getObjLabelAndName(parent)))
-            if parent.role == rolenames.ROLE_FRAME:
-                list[0] = parent
-            if parent.role == rolenames.ROLE_TABLE:
-                list[1] = parent
-            parent = parent.parent
-
-        return list
-
     def _getStatusBar(self, obj):
         """Gets the status bar.
         """
@@ -1210,31 +1094,14 @@ class WhereAmI:
         utterances = []
 
         if self._statusBar.childCount == 0:
-            text = _("%s") % self._getObjName(self._statusBar)
+            text = self._getObjName(self._statusBar)
             utterances.append(text)
         else:
             for i in range(0, self._statusBar.childCount):
                 child = self._statusBar.child(i)
-                text = _("%s") % self._getObjName(child)
+                text = self._getObjName(child)
                 utterances.append(text)
 
         debug.println(self._debugLevel, "statusbar utterances=%s" % \
                       utterances)
         speech.speakUtterances(utterances)
-
-    def _speakCalcStatusBar(self):
-        """Speaks the OpenOffice Calc statusbar.
-        """
-
-        if not self._statusBar:
-            return
-
-        utterances = []
-        for i in range(0, self._statusBar.childCount):
-            child = self._statusBar.child(i)
-            text = _("%s") % self._getObjName(child)
-            utterances.append(text)
-
-        debug.println(self._debugLevel, "Calc statusbar utterances=%s" % \
-                      utterances)
-        speech.speakUtterances(utterances)
